Please reply using this URL only: http://bugs.wpkg.org/show_bug.cgi?id=14
------- Additional Comments From [EMAIL PROTECTED] 2006-02-06 08:23 -------
Hi
You were right, i've mixed up some files and the patch was wrong. Now it should
be diffed to the right file.
--- wpkg.js Sun Feb 5 19:22:00 2006
+++ ../wpkg-0.9.3-test1/wpkg.js Mon Jan 30 10:47:53 2006
@@ -1,6 +1,6 @@
/*******************************************************************************
*
* WPKG 0.9.3 - Windows Packager
* Copyright 2003 Jerry Haltom
* Copyright 2005 Tomasz Chmielewski <tch (at) wpkg . org>
* Copyright 2005 Aleksander Wysocki <papopypu (at) op . pl>
@@ -347,7 +347,7 @@
*/
function showUsage() {
var message = "";
- message += "WPKG 0.9.3 - Windows Packager\n";
+ message += "WPKG 0.9.3-test1 - Windows Packager\n";
message += "Copyright 2004 Jerry Haltom\n";
message += "Copyright 2005 Tomasz Chmielewski <tch (at) wpkg . org>\n";
message += "Copyright 2005 Aleksander Wysocki <papopypu (at) op . pl>\n";
@@ -589,7 +589,8 @@
packageId + "']");
if (executeAttr == "once") {
- if (null == installedPackage) {
+ if ((null == installedPackage) |
+ ((null != installedPackage) &&
(parseInt(installedPackage.getAttribute("revision")) < packageRev )) ) {
try {
if (notifyAttr != "false") {
@@ -1,6 +1,6 @@
/*******************************************************************************
*
- * WPKG 0.9.3 - Windows Packager
+ * WPKG 0.9.3-test1 - Windows Packager
* Copyright 2003 Jerry Haltom
* Copyright 2005 Tomasz Chmielewski <tch (at) wpkg . org>
notifyUserStart();
--
Configure bugmail: http://bugs.wpkg.org/userprefs.cgi?tab=email
------- You are receiving this mail because: -------
You are the QA contact for the bug, or are watching the QA contact.
-------------------------------------------------------
This SF.net email is sponsored by: Splunk Inc. Do you grep through log files
for problems? Stop! Download the new AJAX search engine that makes
searching your log files as easy as surfing the web. DOWNLOAD SPLUNK!
http://sel.as-us.falkag.net/sel?cmd=lnk&kid=103432&bid=230486&dat=121642
_______________________________________________
wpkg-users mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/wpkg-users